# ==================================================================
# Plugins::Tables - Auto Generated Install Module
#
#   Plugins::Tables
#   Author  : Jonathan Gamble
#   Version : 1.0
#   Updated : Fri Aug  4 19:22:14 2006
#
# ==================================================================
#

package Plugins::Tables;
# ==================================================================
use strict;
use vars  qw/$VERSION $DEBUG $NAME $META/;
use GT::Base;
use GT::Plugins qw/STOP CONTINUE/;
use Links qw/:objects/;

$VERSION = '1.0.2';
$DEBUG   = 0;
$NAME    = 'Tables';
# Inhert from base class for debug and error methods
@Plugins::Tables::ISA = qw(GT::Base);

$META = {
    'author' => 'Jonathan Gamble',
    'description' => 'This simple plugin prints all of your SQL tables from the def files.  It allows you to create, drop, and edit the table data (from the existing Links tools) and automatically updates the def files.  This is good for those of us who use more than just GT databases.',
    'license' => 'Freeware',
    'prog_ver' => '3.1.0',
    'url' => 'http://www.gossamer-threads.com/perl/gforum/gforum.cgi?post=293017',
    'version' => '1.0.1'
};


sub pre_install {
# -----------------------------------------------------------------------------
# This function displays an HTML formatted message that will display any
# instructions/information to the user before they install the plugin.
#
    my $inst_msg = 'This will copy the new table.cgi to the admin directory and create a link to it.';

    return $inst_msg;
}

sub pre_uninstall {
# -----------------------------------------------------------------------------
# This function displays an HTML formatted message that will display any
# instructions/information to the user before they remove the plugin.
#
    my $uninst_msg = 'This will delete the tables.cgi file from the admin directory and delete the link to it.';

    return $uninst_msg;
}

sub install {
# -----------------------------------------------------------------------------
# This function does the actual installation.  Its first argument is a plugin
# manager which you can use to register hooks, install files, add menu options,
# etc.  The second argument is a GT::Tar object which you can use to access any
# files in your plugin module.
#
# You should return an HTML formatted string that will be displayed to the
# user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::Tables::error
#
    my ($mgr, $tar) = @_;
    
    $mgr->install_menu('Tables', [['Tables Editor', 'tables.cgi']]);

# Silence warnings
    $GT::Tar::error ||= '';

# The following section will unarchive attached files into the proper location.
    my $file;

# Copying tables.cgi to $CFG->{admin_root_path} directory.
    $file = $tar->get_file('tables.cgi');
# Get the entire code as a string.
        my $code = $file->body_as_string;
# Replace the path to perl with the users perl.
	$code =~ s/^#!(.*)/#!$CFG->{path_to_perl}/;
# Replace the use lib with the users admin directory.
	$code =~ s/use lib '[^']+'/use lib '$CFG->{admin_root_path}'/;
        $code =~ s,Links::init\('[^']+'\),Links::init('$CFG->{admin_root_path}'),;
# Put the new contents in the file
    $file->body ($code);
    $file->name("$CFG->{admin_root_path}/tables.cgi");
    $file->write or return Plugins::Tables->error("Unable to extract file '$CFG->{admin_root_path}/tables.cgi': $GT::Tar::error", 'WARN');
# Set permissions
    chmod (0755, $file->name);

    return "The plugin has been successfully installed!";
}

sub uninstall {
# -----------------------------------------------------------------------------
# This function removes the plugin.  Its first argument is also a plugin
# manager which you can use to register hooks, install files, add menu options,
# etc. You should return an HTML formatted string that will be displayed to the
# user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::Tables::error
#
    my $mgr = shift;
        $mgr->uninstall_menu('Tables', [['Tables Editor', 'tables.cgi']]);

# delete the file

    unlink ("$CFG->{admin_root_path}/tables.cgi") or return Plugins::Tables->error("Unable to delete file '$CFG->{admin_root_path}/tables.cgi': $GT::Tar::error", 'WARN');

    return "The plugin has been successfully removed!";
}

1;
